snntorch.utils
---------------------

:mod:`snntorch.utils` contains a handful of utility functions for handling datasets.

.. automodule:: snntorch.utils
   :members:
   :undoc-members:
   :show-inheritance:
